package com.srs.teacher.mapper;

import java.util.List;

import com.srs.teacher.domain.SysTeacherGuidance;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * guidanceMapper接口
 *
 * @author srs
 * @date 2024-06-29
 */
public interface SysTeacherGuidanceMapper extends BaseMapper<SysTeacherGuidance> {
    /**
     * 查询guidance
     *
     * @param guidanceId guidance主键
     * @return guidance
     */
    public SysTeacherGuidance selectSysTeacherGuidanceByGuidanceId(Long guidanceId);

    /**
     * 查询guidance列表
     *
     * @param sysTeacherGuidance guidance
     * @return guidance集合
     */
    List<SysTeacherGuidance> selectSysTeacherGuidanceList(SysTeacherGuidance sysTeacherGuidance);

    /**
     * 新增guidance
     *
     * @param sysTeacherGuidance guidance
     * @return 结果
     */
    int insertSysTeacherGuidance(SysTeacherGuidance sysTeacherGuidance);

    /**
     * 修改guidance
     *
     * @param sysTeacherGuidance guidance
     * @return 结果
     */
    int updateSysTeacherGuidance(SysTeacherGuidance sysTeacherGuidance);

    /**
     * 删除guidance
     *
     * @param guidanceId guidance主键
     * @return 结果
     */
    int deleteSysTeacherGuidanceByGuidanceId(Long guidanceId);

    /**
     * 批量删除guidance
     *
     * @param guidanceIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysTeacherGuidanceByGuidanceIds(Long[] guidanceIds);
}
